OC.L10N.register(
    "core",
    {
    "Please select a file." : "Veldu skrá.",
    "File is too big" : "Skrá er of stór",
    "The selected file is not an image." : "Valda skráin er ekki mynd.",
    "The selected file cannot be read." : "Ekki hægt að lesa völdu skrána.",
    "Invalid file provided" : "Ógild skrá gefin",
    "No image or file provided" : "Engin mynd eða skrá gefin",
    "Unknown filetype" : "Óþekkt skráartegund",
    "Invalid image" : "Ógild mynd",
    "An error occurred. Please contact your admin." : "Villa kom upp. Hafðu samband við kerfisstjóra.",
    "No temporary profile picture available, try again" : "Engin bráðabirgða einkennismynd er tiltæk, reyndu aftur",
    "No crop data provided" : "Enginn gögn um utanskurð gefin",
    "No valid crop data provided" : "Enginn gild gögn um utanskurð gefin",
    "Crop is not square" : "Utanskurður er ekki ferningslaga",
    "State token does not match" : "Stöðuteikn samsvarar ekki",
    "Could not complete login" : "Gat ekki lokið innskráningu",
    "Your login token is invalid or has expired" : "Innskráningartákn er ógilt eða útrunnið",
    "Password reset is disabled" : "Endurstilling lykilorðs er óvirk",
    "Couldn't reset password because the token is invalid" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er ógilt",
    "Couldn't reset password because the token is expired" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er útrunnið",
    "%s password reset" : "%s lykilorð endurstillt",
    "Password reset" : "Endurstilling lykilorðs",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi hnapp til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi tengil til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
    "Reset your password" : "Endurstilltu lykilorðið þitt",
    "Some of your link shares have been removed" : "Sumir tenglar þnir  sameignir hafa verið fjarlægðir",
    "Preparing update" : "Undirbý uppfærslu",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Þrep viðgerðar:",
    "Repair info:" : "Viðgerðarupplýsingar:",
    "Repair warning:" : "Viðvörun vegna viðgerðar:",
    "Repair error:" : "Villa í viðgerð:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Endilega notaðu uppfærslutólið af skipanalínu, því sjálfvirkar uppfærslur eru gerðar óvirkar í config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Athuga töflu %s",
    "Turned on maintenance mode" : "Kveikt á viðhaldsham",
    "Turned off maintenance mode" : "Slökkt á viðhaldsham",
    "Maintenance mode is kept active" : "Viðhaldsham er haldið virkum",
    "Updating database schema" : "Uppfæri gagnagrunnsskema",
    "Updated database" : "Uppfærði gagnagrunn",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
    "Checked database schema update" : "Athugaði uppfærslu á gagnagrunnsskema.",
    "Checking updates of apps" : "Athuga með uppfærslur á öppum",
    "Checking for update of app \"%s\" in appstore" : "Athuga með uppfærslur á \"%s\"-forriti í hugbúnaðarsafni",
    "Update app \"%s\" from appstore" : "Uppfæra \"%s\" úr hugbúnaðarsafni",
    "Checked for update of app \"%s\" in appstore" : "Athugaði með uppfærslur á \"%s\"-forriti í hugbúnaðarsafni",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Athuga hvort hægt sé að uppfæra gagnagrunnsskema fyrir %s (þetta getur tekið langan tíma ef gagnagrunnurinn er mjög stór)",
    "Checked database schema update for apps" : "Athugaði uppfærslu á gagnagrunnsskema fyrir öpp",
    "Updated \"%1$s\" to %2$s" : "Uppfærði \"%1$s\" í %2$s",
    "Set log level to debug" : "Setja annálsstig á aflúsun",
    "Reset log level" : "Frumstilla annálsstig",
    "Starting code integrity check" : "Ræsi athugun á áreiðanleika kóða",
    "Finished code integrity check" : "Lauk athugun á áreiðanleika kóða",
    "%s (incompatible)" : "%s (ósamhæft)",
    "Following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
    "Already up to date" : "Allt uppfært nú þegar",
    "Very weak password" : "Mjög veikt lykilorð",
    "Weak password" : "Veikt lykilorð",
    "So-so password" : "Miðlungs lykilorð",
    "Good password" : "Gott lykilorð",
    "Strong password" : "Sterkt lykilorð",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Vefþjónninn er ekki enn sett upp á réttan hátt til að leyfa skráasamstillingu því WebDAV viðmótið virðist vera skemmt.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Vefþjónninn þinn er ekki uppsettur þannig að hann geti leyst \"{url}\". Frekari upplýsingar er að finna í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Það lítur út eins og að PHP sé ekki rétt sett upp varðandi fyrirspurnir um umhverfisbreytur. Prófun með getenv(\"PATH\") skilar auðu svari.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Endilega skoðaðu <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjöl uppsetningarinnar ↗</a> varðandi athugasemdir vegna uppsetningar PHP og sjálfa uppsetningu PHP-þjónsins, Sérstaklega ef þú notar php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Skrifvarða stillingaskráin hefur verið virkjuð. Þetta kemur í veg fyrir að hægt sé að sýsla með sumar stillingar í gegnum vefviðmótið. Að auki þarf þessi skrá að vera skrifanleg við hverja uppfærslu.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Gagnagrunnurinn keyrir ekki með \"READ COMMITTED\" færsluaðgreiningarstiginu. Þetta getur valdið vandamálum þegar margar aðgerðir eru keyrðar í einu.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP-eininguna \"fileinfo\" vantar. Við mælum eindregið með notkun þessarar einingar til að fá bestu útkomu við greiningu á MIME-skráagerðum.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "Færslulæsing skráa (transactional file locking) er óvirk, þetta gæti leitt til vandamála út frá forgangsskilyrðum (race conditions). Virkjaðu 'filelocking.enabled' í config.php til að forðast slík vandamál. Skoðaðu <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölin ↗</a> til að sjá nánari upplýsingar.",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "Ef uppsetningin þín er ekki á rót lénsins og þú notar cron stýrikerfisins, þá geta komið upp vandamál við gerð URL-slóða. Til að forðast slík vandamál, skaltu stilla \"overwrite.cli.url\" valkostinn í config.php skránni þinni á slóð vefrótarinnar (webroot) í uppsetningunni (tillaga: \"{suggestedOverwriteCliURL}\")",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ekki var hægt að keyra cron-verkið á skipanalínu. Eftirfarandi tæknilegar villur komu upp:",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "Síðasta keyrsla bakgrunnsverks var keyrt {relativeTime}. Eitthvað er ekki eins og það á að sér að vera.",
    "Check the background job settings" : "Athugaðu stillingar bakgrunnsvinnslunnar",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Þessi þjónn er ekki með virka nettengingu: ekki náðis tenging við fjölmarga endapunkta. Þetta þýðir að sumir eiginleikar eins og að virkja ytri gagnageymslu, tilkynningar um uppfærslur eða uppsetningu á forritum þriðja aðila, mun ekki virka. Fjartengdur aðgangur að skrám og sending tilkynninga í tölvupósti virka líklega ekki heldur. Við leggjum til að internettenging sé virkjuð fyrir þennan vefþjón ef þú vilt hafa alla eiginleika tiltæka.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Ekkert skyndiminni (cache) hefur verið stillt. Til að auka afköst ættirðu að setja upp skyndiminni (með memcache) ef það er tiltækt. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Enginn hentugur gagnagjafi fyrir handahófsreikning fannst fyrir PHP, sem er mjög óráðlegt af öryggisástæðum. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Þú ert að keyra PHP {version}. Við hvetjum þig til að uppfæra PHP útgáfuna til að njóta <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">afkastaaukningar og öryggisuppfærslna frá PHP Group</a> um leið og dreifingin þín styður það.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Þú ert núna að keyra PHP 5.6. Núverandi aðalútgáfa Nextcloud er sú síðasta sem  mun virka á PHP 5.6. Mælt er með því að uppfæra PHP í útgáfu 7.0+ til að eiga möguleika á að uppfæra í Nextcloud 14.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Uppsetning gagnstæðs milliþjónshauss (reverse proxy header) er röng, eða að þú ert að tengjast Nextcloud frá treystum milliþjóni Ef þú ert ekki að tengjast Nextcloud frá treystum milliþjóni, þá er þetta er öryggisvandamál og getur leyft árásaraðilum að dulbúa IP-vistfang þeirra sem sýnilegt Nextcloud. Nánari upplýsingar má finna í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached er sett upp sem dreift skyndiminni, en hinsvegar er ranga PHP-einingin \"memcache\" uppsett. \\OC\\Memcache\\Memcached styður einungis \"memcached\" en ekki \"memcache\". Skoðaðu <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki-síðurnar um báðar einingarnar</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Sumar skrár hafa ekki staðist áreiðanleikaprófun. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar. (<a href=\"{codeIntegrityDownloadEndpoint}\">Listi yfir ógildar skrár…</a> / <a href=\"{rescanEndpoint}\">Endurskanna…</a>)",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "PHP Opcache er ekki hlaðið inn. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Fyrir betri afköst mælum við með</a> því að nota eftirfarandi stillingar í <code>php.ini</code>:",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP Opcache er ekki rétt uppsett. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Fyrir betri afköst mælum við með</a> því að nota eftirfarandi stillingar í <code>php.ini</code>:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-fallið \"set_time_limit\" er ekki tiltækt. Þetta gæti valdið því að skriftur stöðvist í miðri keyrslu og skemmi uppsetninguna þína. Við mælumst til þess að þetta fall sé gert virkt.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-uppsetningin er ekki með stuðning við Free Type. Þetta mun valda því að notendamyndir og stillingaviðmót virki ekki.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Vantar vísinn \"{indexName}\" í töflunni \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Gagnagrunninn vantar nokkra atriðavísa (indexes). Vegna þess að það að bæta atriðavísum við stórar töflur getur tekið töluverðan tíma, þá var þeim ekki bætt við sjálfvirkt. Með því að keyra \"occ db:add-missing-indices\" væri hægt að bæta inn þessum atriðavísum sem vantar, á meðan kerfið er í gangi. Um leið og búið er að bæta inn þessum atriðavísum, munu fyrirspurnir í þessar töflur verða miklu hraðvirkari.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Í þetta kerfistilvik vantar ýmsar PHP-einingar sem mælt er með. Ti að bæta afköst og betri samhæfni er mælt eindregið með að setja þær upp.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Núna er stuðst við SQLite sem bakenda fyrir gagnagrunn. Fyrir stærri uppsetningar mælum við með að skipta yfir í annan gagnagrunnsbakenda.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Mælt er sérstaklega með þessu þegar skjáborðsforritið er notað til að samstilla skrár.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Til að yfirfæra í annan gagnagrunn skaltu nota skipanalínutólið: 'occ db:convert-type', eða lesa <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölin ↗</a>.",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Notkun á innbyggðum php póstsendingum er ekki lengur studd. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Uppfærðu stillingar póstþjónsins þíns ↗<a/>.",
    "The PHP memory limit is below the recommended value of 512MB." : "Minnismörk PHP eru lægri en gildið sem mælt er með; 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Sumar forritamöppur eru í eigu annarra notenda en möppurnar á vefþjóninum. Þetta getur komið upp ef forritin hafa verið sett upp handvirkt. Athugaðu með heimildir á eftirfarandi forritamöppum:",
    "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Gagnamappan og skrárnar þínar eru líklega aðgengilegar öllum af internetinu vegna þess að .htaccess skrá er ekki virk. Við mælum eindregið með að þú stillir vefþjóninn þinn á þann hátt að gagnamappa er ekki lengur aðgengileg eða þú færir gagnamöppu út fyrir skjalarót vefþjóns.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn er ekki stilltur á \"{expected}\". Þetta er möguleg áhætta varðandi  öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn er ekki stilltur á \"{expected}\". Einhverjir eiginleikar gætu virkað ekki rétt, við mælum með því að laga þessa stillingu.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn inniheldur ekki \"{expected}\". Þetta er möguleg áhætta varðandi öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP-hausinn \"{header}\" er ekki stilltur á \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" eða \"{val5}\". Þetta getur lekið upplýsingum um kerfið. Skoðaðu hvað <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C mælir með ↗</a>.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP-hausinn er ekki stilltur á að minnsa kosti \"{seconds}\" sekúndur. Fyrir aukið öryggi mælum við með því að virkja HSTS eins og lýst er í <a href=\"{docUrl}\" rel=\"noreferrer noopener\">öryggisleiðbeiningum ↗ </a>.",
    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
    "restricted" : "takmarkaður aðgangur",
    "invisible" : "ósýnilegt",
    "({scope})" : "({scope})",
    "Delete" : "Eyða",
    "Rename" : "Endurnefna",
    "Collaborative tags" : "Samstarfsmerkingar",
    "No tags found" : "Engin merki fundust",
    "unknown text" : "óþekktur texti",
    "Hello world!" : "Halló heimur!",
    "sunny" : "sólríkt",
    "Hello {name}, the weather is {weather}" : "Halló {name},veðrið er {weather}",
    "Hello {name}" : "Halló {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hér eru leitarniðurstöðurnar þínar<script>alert(1)</script></strong>",
    "new" : "nýtt",
    "_download %n file_::_download %n files_" : ["sækja %n skrá","sækja %n skrár"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppfærslan er í gangi, ef farið er af þessari síðu gæti það truflað ferlið á sumum kerfum.",
    "Update to {version}" : "Uppfæra í {version}",
    "An error occurred." : "Villa átti sér stað.",
    "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppfærslan tókst ekki. Til að fá frekari upplýsingar <a href=\"{url}\">skoðaðu færslu á spjallsvæðinu okkar</a> sem fjallar um þetta mál.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uppfærslan tókst ekki. Skoðaðu annálana á kerfisstjórnunarsíðunni og sendu inn tilkynningu um vandamálið til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud samfélagsins</a>.",
    "Continue to Nextcloud" : "Halda áfram í Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Uppfærslan heppnaðist. Beini þér til Nextcloud eftir %n sekúndu.","Uppfærslan heppnaðist. Beini þér til Nextcloud eftir %n sekúndur."],
    "Searching other places" : "Leitað á öðrum stöðum",
    "No search results in other folders for {tag}{filter}{endtag}" : "Engar leitarniðurstöður í öðrum möppum fyrir {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} leitarniðurstöður í annarri möppu","{count} leitarniðurstöður í öðrum möppum"],
    "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
    "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
    "An internal error occurred." : "Innri villa kom upp.",
    "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
    "Username or email" : "Notandanafn eða tölvupóstur",
    "Username or\temail" : "Notandanafn eða\ttölvupóstur",
    "Password" : "Lykilorð",
    "Log in" : "Skrá inn",
    "Logging in …" : "Skrái inn …",
    "Wrong username or password." : "Rangt notandanafn eða lykilorð.",
    "User disabled" : "Notandi óvirkur",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Við urðum vör við margar misheppnaðar innskráningar í röð frá IP-vistfanginu þínu. Þar með verður næsta innskráning tafin (throttled) um 30 sekúndur.",
    "Reset password" : "Endursetja lykilorð",
    "If it is not there ask your local administrator." : "Ef hann er ekki þar, spurðu þá kerfisstjórann þinn. ",
    "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
    "Password can not be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
    "Back to login" : "Til baka í innskráningu",
    "New password" : "Nýtt lykilorð",
    "I know what I'm doing" : "Ég veit hvað ég er að gera",
    "Forgot password?" : "Gleymdirðu lykilorði?",
    "Settings" : "Stillingar",
    "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
    "Search contacts …" : "Leita í tengiliðum ",
    "No contacts found" : "Engir tengiliðir fundust",
    "Show all contacts …" : "Birta alla tengiliði ...",
    "Install the Contacts app" : "Setja upp tengiliðaforritið",
    "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
    "Looking for {term} …" : "Leita að {term} …",
    "No" : "Nei",
    "Yes" : "Já",
    "No files in here" : "Engar skrár hér",
    "New folder" : "Ný mappa",
    "No more subfolders in here" : "Engar fleiri undirmöppur hér",
    "Name" : "Nafn",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "{newName} already exists" : "{newName} er þegar til",
    "Choose" : "Veldu",
    "Copy" : "Afrita",
    "Move" : "Færa",
    "Error loading file picker template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skráaveljara: {error}",
    "OK" : "Í lagi",
    "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
    "read-only" : "skrifvarið",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} árekstur skráa","{count} árekstrar skráa"],
    "One file conflict" : "Einn árekstur skráa",
    "New Files" : "Nýjar skrár",
    "Already existing files" : "Skrá er nú þegar til",
    "Which files do you want to keep?" : "Hvaða skrám vilt þú vilt halda eftir?",
    "If you select both versions, the copied file will have a number added to its name." : "Ef þú velur báðar útgáfur, þá mun verða bætt tölustaf aftan við heiti afrituðu skrárinnar.",
    "Cancel" : "Hætta við",
    "Continue" : "Halda áfram",
    "(all selected)" : "(allt valið)",
    "({count} selected)" : "({count} valið)",
    "Error loading file exists template" : "Villa við að hlaða inn sniðmáti fyrir skrá-er-til",
    "Pending" : "Í bið",
    "Copy to {folder}" : "Afrita í {folder}",
    "Move to {folder}" : "Færa í {folder}",
    "Saving..." : "Er að vista ...",
    "Authentication required" : "Auðkenningar krafist",
    "This action requires you to confirm your password" : "Þessi aðgerð krefst þess að þú staðfestir lykilorðið þitt",
    "Confirm" : "Staðfesta",
    "Failed to authenticate, try again" : "Tókst ekki að auðkenna, prófaðu aftur",
    "seconds ago" : "sekúndum síðan",
    "Connection to server lost" : "Tenging við miðlara rofnaði",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndu","Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndur"],
    "Add to a project" : "Bæta við verkefni",
    "Show details" : "Birta nánari upplýsingar",
    "Hide details" : "Fela nánari upplýsingar",
    "Rename project" : "Endurnefna verkefni",
    "Failed to rename the project" : "Mistókst að endurnefna verkefnið",
    "Failed to create a project" : "Mistókst að útbúa verkefni",
    "Failed to add the item to the project" : "Mistókst að bæta atriðinu í verkefnið",
    "New in" : "Nýtt í",
    "View changelog" : "Skoða breytingaannál",
    "No action available" : "Engin aðgerð tiltæk",
    "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
    "Personal" : "Einka",
    "Users" : "Notendur",
    "Apps" : "Forrit",
    "Admin" : "Stjórnun",
    "Help" : "Hjálp",
    "Access forbidden" : "Aðgangur bannaður",
    "File not found" : "Skrá finnst ekki",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Skjalið fannst ekki á þjóninum. Hugsanlega hefur sameigninni verið eytt eða sé útrunnin?",
    "Back to %s" : "Til baka í %s",
    "Error" : "Villa",
    "Internal Server Error" : "Innri villa",
    "The server was unable to complete your request." : "Þjóninum tókst ekki að afgreiða beiðnina þína.",
    "If this happens again, please send the technical details below to the server administrator." : "Ef þetta gerist aftur, sendu tæknilegu lýsinguna hér fyrir neðan til kerfisstjóra þjónsins.",
    "More details can be found in the server log." : "Nánari upplýsingar er að finna í atburðaskrá (annál) þjónsins.",
    "Technical details" : "Tæknilegar upplýsingar",
    "Remote Address: %s" : "fjartengt vistfang: %s",
    "Request ID: %s" : "Beiðni um auðkenni: %s",
    "Type: %s" : "Tegund: %s",
    "Code: %s" : "Kóði: %s",
    "Message: %s" : "Skilaboð: %s",
    "File: %s" : "Skrá: %s",
    "Line: %s" : "Lína: %s",
    "Trace" : "Rekja",
    "Security warning" : "Öryggisviðvörun",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlarann almennilega, skaltu skoða <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hjálparskjölin</a>.",
    "Create an <strong>admin account</strong>" : "Útbúa <strong>kerfisstjóraaðgang</strong>",
    "Username" : "Notandanafn",
    "Storage & database" : "Geymsla & gagnagrunnur",
    "Data folder" : "Gagnamappa",
    "Configure the database" : "Stilla gagnagrunninn",
    "Only %s is available." : "Aðeins %s eru laus.",
    "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
    "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
    "Database user" : "Notandi gagnagrunns",
    "Database password" : "Lykilorð gagnagrunns",
    "Database name" : "Heiti gagnagrunns",
    "Database tablespace" : "Töflusvæði gagnagrunns",
    "Database host" : "Netþjónn gagnagrunns",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Taktu fram númer gáttar ásamt nafni hýsilvélar (t.d., localhost:5432).",
    "Performance warning" : "Afkastaviðvörun",
    "You chose SQLite as database." : "Þú valdir SQLite sem gagnagrunn.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ætti aðeins að nota fyrir lágmarksuppsetningar og til prófana. Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ef verið er að nota biðlaraforrit til að samstilla skrár, þá er ekki mælt með notkun SQLite.",
    "Finish setup" : "Ljúka uppsetningu",
    "Finishing …" : "Að klára ...",
    "Need help?" : "Þarftu hjálp?",
    "See the documentation" : "Sjá hjálparskjölin",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Þetta forrit krefst JavaScript fyrir rétta virkni. {linkstart} virkjaðu JavaScript {linkend} og endurlestu síðan síðuna.",
    "Get your own free account" : "Fáðu þér eigin ókeypis aðgang",
    "Skip to main content" : "Sleppa og fara í meginefni",
    "Skip to navigation of app" : "Hlaupa yfir í flakk innan forrits",
    "More apps" : "Fleiri forrit",
    "More" : "Meira",
    "More apps menu" : "Valmynd með fleiri forrit",
    "Search" : "Leita",
    "Reset search" : "Núllstilla leit",
    "Contacts" : "Tengiliðir",
    "Contacts menu" : "Tengiliðavalmynd",
    "Settings menu" : "Stillingavalmynd",
    "Confirm your password" : "Staðfestu lykilorðið þitt",
    "Connect to your account" : "Tengdu við notandaaðganginn þinn",
    "Please log in before granting %1$s access to your %2$s account." : "Skráði þig inn áður en þú leyfir %1$s aðgang að %2$s notandaaðgangnum þínum.",
    "App token" : "Teikn forrits",
    "Grant access" : "Veita aðgengi",
    "Alternative log in using app token" : "Önnur innskráning með forritsteikni",
    "Account access" : "Aðgangur að notandaaðgangi",
    "You are about to grant %1$s access to your %2$s account." : "Þú ert að fara að leyfa \"%1$s\" aðgang að %2$s notandaaðgangnum þínum.",
    "Account connected" : "Aðgangur er tengdur",
    "This share is password-protected" : "Þessi sameign er varin með lykilorði",
    "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
    "Two-factor authentication" : "Tveggja-þrepa auðkenning",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu aukaþrep til auðkenningar:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Gat ekki hlaðið inn a.m.k. einni af virkum tveggja-þrepa auðkenningaraðferðunum þínum. Hafðu samband við kerfisstjóra.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnum þínum. Hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
    "Set up two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Notaðu einn af öryggisafritunarkóðunum þínum til að skrá þig inn, eða hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
    "Use backup code" : "Nota öryggisafritskóða",
    "Cancel log in" : "Hætta við innskráningu",
    "Setup two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
    "Error while validating your second factor" : "Villa við að sannreyna seinna þrepið",
    "Access through untrusted domain" : "Tenging frá ótreystu léni",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Frekari upplýsingar um hvernig hægt er að stilla þetta má finna í %1$shjálparskjölunum%2$s.",
    "App update required" : "App þarfnast uppfærslu ",
    "%1$s will be updated to version %2$s" : "%1$s verður uppfært í útgáfu %2$s.",
    "These apps will be updated:" : "Eftirfarandi öpp verða uppfærð:",
    "These incompatible apps will be disabled:" : "Eftirfarandi forrit eru ósamhæfð og verið gerð óvirk: %s",
    "The theme %s has been disabled." : "Þema %s hefur verið gert óvirkt.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gakktu úr skugga um að gagnagrunnurinn, config mappan og gagnamappan hafi verið öryggisafritaðar áður en lengra er haldið.",
    "Start update" : "Hefja uppfærslu",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Til að forðast að falla á tímamörkum með stærri uppsetningar, getur þú í staðinn keyrt eftirfarandi skipun úr uppsetningarmöppunni:",
    "Detailed logs" : "Ítarlegar atvikaskrár",
    "Update needed" : "Þarfnast uppfærslu",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Endilega notaðu uppfærslutólið af skipanalínu, því þú ert með mjög stóra uppsetningu með fleiri en 50 notendum.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Til að fá hjálp er best að skoða fyrst  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hjálparskjölin</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ég veit að ef ég held uppfærslunni áfram í gegnum vefviðmótið, þá er sú áhætta fyrir hendi að beiðnin falli á tímamörkum, sem aftur gæti valdið gagnatapi - en ég á öryggisafrit og veit hvernig ég get endurheimt uppsetninguna mína ef aðgerðin misferst.",
    "Upgrade via web on my own risk" : "Uppfæra með vefviðmóti á mína eigin ábyrgð",
    "Maintenance mode" : "Viðhaldshamur",
    "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
    "This page will refresh itself when the instance is available again." : "Þessi síða mun uppfæra sig þegar tilvikið er í boði á ný.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti því það er ekkert gilt tölvupóstfang fyrir þennan notanda. Hafðu samband við kerfisstjóra.",
    "Couldn't send reset email. Please make sure your username is correct." : "Gat ekki sent endurstillingu í tölvupósti. Gakktu úr skugga um að notandanafn þitt sé rétt.",
    "Dismiss" : "Hafna",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Það er engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt.<br />Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. <br />Viltu halda áfram?",
    "Sending email …" : "Sendi tölvupóst ...",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} eldra en útgáfa {version} er uppsett, en vegna stöðugleika og afkasta mælum við með að útgáfa {name} verði sett upp.",
    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : " Þú ert að tengjast þessu vefsvæði með HTTP. Við mælum eindregið með að þú stillir þjóninn á að krefjast HTTPS í staðinn eins og lýst er í <a href=\"{docUrl}\">öryggisleiðbeiningunum okkar ↗</a>.",
    "Shared" : "Deilt",
    "Shared with" : "Deilt með",
    "Shared by" : "Deilt af",
    "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
    "Choose a password for the public link or press the \"Enter\" key" : "Veldu þér lykilorð fyrir opinbera tengilinn eða ýttu á \"Ente\" lykilinn",
    "Copied!" : "Afritað!",
    "Copy link" : "Afrita tengil",
    "Not supported!" : "Óstutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "Unable to create a link share" : "Gat ekki búið til sameignartengil",
    "Unable to toggle this option" : "Tekst ekki að víxla þessum valkosti af/á",
    "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
    "Link" : "Tengill",
    "Hide download" : "Fela niðurhal",
    "Password protection enforced" : "Gerði verndun með lykilorði nauðsynlega",
    "Password protect" : "Verja með lykilorði",
    "Allow editing" : "Leyfa breytingar",
    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
    "Send" : "Senda",
    "Allow upload and editing" : "Leyfa innsendingu og breytingar",
    "Read only" : "Skrifvarið",
    "File drop (upload only)" : "Slepping skráa (einungis innsending)",
    "Expiration date enforced" : "Gerði gildistíma nauðsynlegan",
    "Set expiration date" : "Setja gildistíma",
    "Expiration" : "Rennur út",
    "Expiration date" : "Gildir til",
    "Note to recipient" : "Minnispunktur til viðtakanda",
    "Unshare" : "Hætta deilingu",
    "Delete share link" : "Eyða tengli á sameign",
    "Add another link" : "Bæta við öðrum tengli",
    "Password protection for links is mandatory" : "Verndun tengla með lykilorði er skylda",
    "Share to {name}" : "Deila til {name}",
    "Share link" : "Deila tengli",
    "New share link" : "Nýr tengill á sameign",
    "Created on {time}" : "Búið til {time}",
    "Password protect by Talk" : "Verja með lykilorði í gegnum Talk",
    "Could not unshare" : "Gat ekki hætt deilingu",
    "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
    "Shared with you and {circle} by {owner}" : "Deilt með þér og {circle} af {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Deilt með þér og samtalinu {conversation} af {owner}",
    "Shared with you in a conversation by {owner}" : "Deilt með þér í samtali af {owner}",
    "Shared with you by {owner}" : "Deilt með þér af {owner}",
    "Choose a password for the mail share" : "Veldu lykilorð fyrir póstsameign",
    "group" : "hópur",
    "remote" : "fjartengt",
    "remote group" : "fjartengdur hópur",
    "email" : "tölvupóstur",
    "conversation" : "samtal",
    "shared by {sharer}" : "deilt af {sharer}",
    "Can reshare" : "Getur endurdeilt",
    "Can edit" : "Getur breytt",
    "Can create" : "Getur búið til",
    "Can change" : "Getur skipt um",
    "Can delete" : "Getur eytt",
    "Access control" : "Aðgangsstýring",
    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} deildi með tengli",
    "Error while sharing" : "Villa við deilingu",
    "Share details could not be loaded for this item." : "Ekki tókst að hlaða inn upplýsingum um sameign varðandi þetta atriði.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Það þarf a.m.k. {count} staf til að sjálfvirk útfylling virki","Það þarf a.m.k. {count} stafi til að sjálfvirk útfylling virki"],
    "This list is maybe truncated - please refine your search term to see more results." : "Þessi listi gæti verið stytt útgáfa - þrengdu leitarskilyrðin til að sjá fleiri niðurstöður.",
    "No users or groups found for {search}" : "Engir notendur eða hópar fundust í {search}",
    "No users found for {search}" : "Engir notendur fundust með {search}",
    "An error occurred (\"{message}\"). Please try again" : "Villa kom upp (\"{message}\"). Endilega reyndu aftur",
    "An error occurred. Please try again" : "Villa kom upp. Endilega reyndu aftur",
    "Home" : "Heima",
    "Work" : "Vinna",
    "Other" : "Annað",
    "{sharee} (remote group)" : "{sharee} (fjartengdur hópur)",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Deila",
    "Name or email address..." : "Nafn eða tölvupóstfang...",
    "Name or federated cloud ID..." : "Nafn eða skýjasambandsauðkenni (Federated Cloud ID)...",
    "Name, federated cloud ID or email address..." : "Nafn, skýjasambandsauðkenni eða tölvupóstfang...",
    "Name..." : "Nafn...",
    "Error removing share" : "Villa við að fjarlægja sameign",
    "SQLite will be used as database." : "SQLite verður notað sem gagnagrunnur.",
    "For larger installations we recommend to choose a different database backend." : "Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Sérstaklega þegar verið er að nota skjáborðsforritið til að samræma skrár, þá er ekki mælt með notkun SQLite.",
    "Wrong password." : "Rangt lykilorð.",
    "New Password" : "Nýtt lykilorð",
    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn.",
    "Search globally" : "Leita allstaðar",
    "Your client should now be connected! You can close this window." : "Biðlaraforritið þitt ætti núna að vera tengt! Þú mátt loka þessum glugga."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
